CustomMenuBuilderDelegate<T> class final

Inheritance

Constructors

CustomMenuBuilderDelegate(DropdownMenuBuilder<T> builder)
const

Properties

builder → DropdownMenuBuilder<T>
The builder that will be used to build the menu items, instead of using a ListView
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, List<DropdownItem<T>> items, bool loading) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant CustomMenuBuilderDelegate<T> other) → bool
The equality operator.
override