ListViewMenuBuilderDelegate<T> class final

Inheritance

Constructors

ListViewMenuBuilderDelegate({required MenuItemBuilder<T> itemBuilder, required DropdownMenuPosition position, IndexedWidgetBuilder? separatorBuilder, WidgetBuilder? loadingBuilder, WidgetBuilder? emptyListBuilder})
const

Properties

emptyListBuilder → WidgetBuilder?
The builder that will be used to build the empty list indicator,
final
hashCode → int
The hash code for this object.
no setteroverride
itemBuilder → MenuItemBuilder<T>
The builder that will be used to build the menu items.
final
loadingBuilder → WidgetBuilder?
The builder that will be used to build the loading indicator, when DropdownController.loading is true.
final
position → DropdownMenuPosition
The position that will be used to position the dropdown menu.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separatorBuilder → IndexedWidgetBuilder?
The builder that will be used to build the separators.
final

Methods

build(BuildContext context, List<DropdownItem<T>> items, bool loading) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant ListViewMenuBuilderDelegate<T> other) → bool
The equality operator.
override